<?php

class TBit_Gradio {

    protected $loader;

    protected $plugin_name;
	protected $plugin_nice_name;
	protected $default_hosts;
    protected $version;

    public function __construct($run_loaders_and_hooks = true) {
        if( defined( 'TBIT_GRADIO_VERSION' ) ) {
            $this->version = TBIT_GRADIO_VERSION;
        } else {
            $this->version = '0.0.1';
        }

        $this->plugin_name = 'tbit-embed-ai';
		$this->plugin_nice_name = 'Embed AI by ThinkingBit';
		$this->default_hosts = [
			"gradio.s3-us-west-2.amazonaws.com",
		];

		if ($run_loaders_and_hooks) {
	        $this->load_dependencies();
	        $this->define_admin_hooks();
	        $this->define_public_hooks();
		
			$this->add_borlabs_content_blocker();
			$this->add_complianz_content_blocker();
		}
    }

    private function load_dependencies() {
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-tbit-gradio-loader.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-tbit-gradio-admin.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-tbit-gradio-public.php';

        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'blocks/blocks.php';
        require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/tinymce.php';
		
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'gdpr/filters.php';

        $this->loader = new TBit_Gradio_Loader();
    }

    private function define_admin_hooks() {
        $plugin_admin = new TBit_Gradio_Admin( $this->get_plugin_name(), $this->get_version() );
    }

    private function define_public_hooks() {
        $plugin_public = new TBit_Gradio_Public( $this->get_plugin_name(), $this->get_version() );

        $this->loader->add_action('init', $plugin_public, 'register_shortcodes');
    }
	
	private function add_borlabs_content_blocker() {
		if (function_exists("BorlabsCookieHelper")) {
			$contentBlockerId = $this->plugin_name;
			$name = $this->plugin_nice_name;
			$hosts = $this->default_hosts;
			$previewHTML = "";
			BorlabsCookieHelper()->addContentBlocker($contentBlockerId, $name, $description = '', $privacyPolicyURL = '', $hosts, $previewHTML, $previewCSS = '', $globalJS = '', $initJS = '', $settings = [], $status = false, $undeletable = false);
		}
	}
	
	private function add_complianz_content_blocker() {
		add_filter( 'cmplz_integrations', 'tbit_embed_ai_complianz_integration');
		add_filter( 'cmplz_integration_path', 'tbit_embed_ai_complianz_integration_path', 10, 2 );
	}

    public function run() {
        $this->loader->run();
    }

    public function get_loader() {
        return $this->loader;
    }

    public function get_plugin_name() {
        return $this->plugin_name;
    }

    public function get_version() {
        return $this->version;
    }
	
    public function get_plugin_nice_name() {
        return $this->plugin_nice_name;
    }
	
    public function get_default_hosts() {
        return $this->default_hosts;
    }
}